# TDSControl - Python
A Python wrapper for the TDS Control library (https://github.com/AppeltansPieter/TDSControl).

## Installation

- Option 1 (suggested): Install via pip
```bash
pip install tdscontrol
```
- Option 2: Build from source (requires [CMake](https://cmake.org/) and a compatible C++ compiler:
```
git clone https://github.com/AppeltansPieter/TDSControl-python.git
cd TDSControl-python
git submodule update --init --recursive
pip install .
```
- Option 3: Download the the relevant release files and install using `pip`
```bash
pip install .
```

## Documentation

Coming soon.
